@@ -9,473 +9,513 @@
         <translation>MX Pomocník se sítí</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="70"/>
-        <source>Status</source>
-        <translation>Stav</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="76"/>
-        <source>IP address</source>
-        <translation>IP adresa</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="112"/>
-        <source>Hardware detected</source>
-        <translation>Nalezen hardware</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="143"/>
-        <location filename="../mainwindow.ui" line="389"/>
-        <location filename="../mainwindow.ui" line="502"/>
-        <source>Re-scan</source>
-        <translation>Znovu vyhledat</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="215"/>
-        <source>Active interface</source>
-        <translation>Aktivní rozhraní</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="231"/>
-        <source>WiFi status</source>
-        <translation>WiFi status</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="253"/>
-        <source>Unblocks all soft/hard blocked wireless devices</source>
-        <translation>Odblokuje všechny blokované bezdrátové zařízení</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="256"/>
-        <source>Unblock WiFi Devices</source>
-        <translation>Odblokovat WiFi </translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="288"/>
-        <source>Linux drivers</source>
-        <translation>Ovladače Linuxu</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="300"/>
-        <source>Associated Linux drivers</source>
-        <translation>Přiřazené ovladače Linuxu</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="309"/>
-        <source>Load Driver</source>
-        <translation>Načist ovladač</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="372"/>
-        <source>Unload Driver</source>
-        <translation>Uvolnit ovladač</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="409"/>
-        <source>Block Driver</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="428"/>
-        <source>Windows drivers</source>
-        <translation>Windows ovladače</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="434"/>
-        <source>Available Windows drivers</source>
-        <translation>Dostupné Windows ovladače</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="468"/>
-        <source>Remove Driver</source>
-        <translation>Odstranit ovladač</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="479"/>
-        <source>Add Driver</source>
-        <translation>Přidat ovladač</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="520"/>
-        <source>About NDISwrapper</source>
-        <translation>O programu NDISwrapper</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="532"/>
-        <source>Install NDISwrapper</source>
-        <translation>Instalovat NDISwrapper</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="543"/>
-        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
-        <translation>Za účelem možnosti použití ovladačů Windows musíte nejdřív nainstalovat NDISwrapper</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="559"/>
-        <source>Uninstall NDISwrapper</source>
-        <translation>Odinstalovat NDISwrapper</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="591"/>
-        <source>Net diagnostics</source>
-        <translation>Diagnostika sítě</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="603"/>
-        <source>Ping</source>
-        <translation>Ping</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="609"/>
-        <location filename="../mainwindow.ui" line="726"/>
-        <source>Target URL:</source>
-        <translation>Cílové URL:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="619"/>
-        <source>Packets</source>
-        <translation>Pakety</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="661"/>
-        <location filename="../mainwindow.ui" line="781"/>
-        <source>Start</source>
-        <translation>Spustit</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="678"/>
-        <location filename="../mainwindow.ui" line="798"/>
-        <source>Clear</source>
-        <translation>Vyčistit</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="692"/>
-        <location filename="../mainwindow.ui" line="812"/>
-        <source>Cancel</source>
-        <translation>Zrušit</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="720"/>
-        <source>Traceroute</source>
-        <translation>Traceroute</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="736"/>
-        <source>Hops</source>
-        <translation>Hops</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="868"/>
+        <location filename="../mainwindow.ui" line="86"/>
         <source>About...</source>
         <translation>O programu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="891"/>
+        <location filename="../mainwindow.ui" line="109"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="959"/>
+        <location filename="../mainwindow.ui" line="177"/>
         <source>&amp;Close</source>
         <translation>&amp;Zavřít</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="966"/>
+        <location filename="../mainwindow.ui" line="184"/>
         <source>Alt+C</source>
         <translation>Alt+C</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="87"/>
-        <source>IP address from router:</source>
-        <translation>IP adresa z routru:</translation>
+        <location filename="../mainwindow.ui" line="219"/>
+        <source>Status</source>
+        <translation>Stav</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="88"/>
-        <source>External IP address:</source>
-        <translation>Externí IP adresa:</translation>
+        <location filename="../mainwindow.ui" line="225"/>
+        <source>IP address</source>
+        <translation>IP adresa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="196"/>
-        <location filename="../mainwindow.cpp" line="210"/>
-        <location filename="../mainwindow.cpp" line="224"/>
-        <source>&amp;Copy</source>
-        <translation>&amp;Kopírovat</translation>
+        <location filename="../mainwindow.ui" line="261"/>
+        <source>Hardware detected</source>
+        <translation>Nalezen hardware</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="198"/>
-        <location filename="../mainwindow.cpp" line="212"/>
-        <location filename="../mainwindow.cpp" line="226"/>
-        <source>Ctrl+C</source>
-        <translation>Ctrl+C</translation>
+        <location filename="../mainwindow.ui" line="280"/>
+        <source>Enable</source>
+        <translation>Zapnout</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="199"/>
-        <location filename="../mainwindow.cpp" line="213"/>
-        <location filename="../mainwindow.cpp" line="227"/>
-        <source>Copy &amp;All</source>
-        <translation>Kopírovat &amp;vše</translation>
+        <location filename="../mainwindow.ui" line="303"/>
+        <location filename="../mainwindow.ui" line="593"/>
+        <location filename="../mainwindow.ui" line="706"/>
+        <source>Re-scan</source>
+        <translation>Znovu vyhledat</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="201"/>
-        <location filename="../mainwindow.cpp" line="215"/>
-        <location filename="../mainwindow.cpp" line="229"/>
-        <source>Ctrl+A</source>
-        <translation>Ctrl+A</translation>
+        <location filename="../mainwindow.ui" line="372"/>
+        <source>Enabled</source>
+        <translation>Zapnuto</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="261"/>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <source>Traceroute not installed</source>
-        <translation>Traceroute není nainstalován</translation>
+        <location filename="../mainwindow.ui" line="377"/>
+        <source>Interface</source>
+        <translation>Interface</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="262"/>
-        <source>Traceroute is not installed, do you want to install it now?</source>
-        <translation>Traceroute není nainstalován, přejete si ho nainstalovat?</translation>
+        <location filename="../mainwindow.ui" line="382"/>
+        <source>Driver</source>
+        <translation>Ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="269"/>
-        <source>Traceroute hasn&apos;t been installed</source>
-        <translation>Traceroute nebyl nainstalován</translation>
+        <location filename="../mainwindow.ui" line="387"/>
+        <source>Description</source>
+        <translation>Popis</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="270"/>
-        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
-        <translation>Traceroute nemůže být nainstalován. Může to být způsobeno tím, že používáte LiveCD nebo nemáte přístup k softvérovým repozitářům.</translation>
+        <location filename="../mainwindow.ui" line="392"/>
+        <source>Vendor</source>
+        <translation>Výrobce</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="279"/>
-        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
-        <translation>Traceroute není nainstalován a nebylo rozpoznáno žádné připojení k Internetu, bez kterého nelze program nainstalovat.</translation>
+        <location filename="../mainwindow.ui" line="397"/>
+        <source>Product</source>
+        <translation>Produkt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="285"/>
-        <location filename="../mainwindow.cpp" line="326"/>
-        <source>No destination host</source>
-        <translation>Žádný cílový host</translation>
+        <location filename="../mainwindow.ui" line="405"/>
+        <source>Disable</source>
+        <translation>Vypnout</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
-        <location filename="../mainwindow.cpp" line="327"/>
-        <source>Please fill in the destination host field</source>
-        <translation>Prosím vyplňte políčko cílový host</translation>
+        <location filename="../mainwindow.ui" line="419"/>
+        <source>Active interface</source>
+        <translation>Aktivní rozhraní</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="440"/>
-        <source>Loaded Drivers</source>
-        <translation>Načtené ovladače</translation>
+        <location filename="../mainwindow.ui" line="435"/>
+        <source>WiFi status</source>
+        <translation>WiFi status</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="449"/>
-        <source>Unloaded Drivers</source>
-        <translation>Nenačtené ovladače</translation>
+        <location filename="../mainwindow.ui" line="457"/>
+        <source>Unblocks all soft/hard blocked wireless devices</source>
+        <translation>Odblokuje všechny blokované bezdrátové zařízení</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="464"/>
-        <source>Blocked Drivers</source>
-        <translation type="unfinished"></translation>
+        <location filename="../mainwindow.ui" line="460"/>
+        <source>Unblock WiFi Devices</source>
+        <translation>Odblokovat WiFi </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="486"/>
-        <source>Blocked Broadcom Drivers</source>
-        <translation type="unfinished"></translation>
+        <location filename="../mainwindow.ui" line="492"/>
+        <source>Linux drivers</source>
+        <translation>Ovladače Linuxu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="894"/>
-        <source>enabled</source>
-        <translation>povoleno</translation>
+        <location filename="../mainwindow.ui" line="504"/>
+        <source>Associated Linux drivers</source>
+        <translation>Přiřazené ovladače Linuxu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="897"/>
-        <source>disabled</source>
-        <translation>zakázáno</translation>
+        <location filename="../mainwindow.ui" line="513"/>
+        <source>Load Driver</source>
+        <translation>Načist ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="900"/>
-        <source>WiFi hardware switch is off</source>
-        <translation>Hardvérový přepínač WiFi je v poloze vypnuto.</translation>
+        <location filename="../mainwindow.ui" line="576"/>
+        <source>Unload Driver</source>
+        <translation>Uvolnit ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="908"/>
-        <source>Locate the Windows driver you want to add</source>
-        <translation>Určit ovladač z Windows, který si přejete přidat</translation>
+        <location filename="../mainwindow.ui" line="613"/>
+        <location filename="../mainwindow.cpp" line="847"/>
+        <source>Block Driver</source>
+        <translation>Zakázat ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="908"/>
-        <source>Windows installation information file (*.inf)</source>
-        <translation>Windows installation information file (*.inf)</translation>
+        <location filename="../mainwindow.ui" line="632"/>
+        <source>Windows drivers</source>
+        <translation>Windows ovladače</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="939"/>
-        <source>*.sys file not found</source>
-        <translation>sobor *.sys nenalezen</translation>
+        <location filename="../mainwindow.ui" line="638"/>
+        <source>Available Windows drivers</source>
+        <translation>Dostupné Windows ovladače</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="939"/>
-        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation>Soubory *.sys musí být umístněny v stejné složce jako soubor *.inf. %1 nelze nalézt</translation>
+        <location filename="../mainwindow.ui" line="672"/>
+        <source>Remove Driver</source>
+        <translation>Odstranit ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="948"/>
-        <source>sys file reference not found</source>
-        <translation>referene soboru *.sys nenalezena</translation>
+        <location filename="../mainwindow.ui" line="683"/>
+        <source>Add Driver</source>
+        <translation>Přidat ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="948"/>
-        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation>Po zanalyzování inf souboru nemůže být určen sys soubor daného ovladače</translation>
+        <location filename="../mainwindow.ui" line="724"/>
+        <source>About NDISwrapper</source>
+        <translation>O programu NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="967"/>
-        <source>Ndiswrapper driver removed.</source>
-        <translation>Ovladač Ndiswrapper odstraněn.</translation>
+        <location filename="../mainwindow.ui" line="736"/>
+        <source>Install NDISwrapper</source>
+        <translation>Instalovat NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="975"/>
-        <source>%1 Help</source>
-        <translation>Nápověda %1</translation>
+        <location filename="../mainwindow.ui" line="747"/>
+        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
+        <translation>Za účelem možnosti použití ovladačů Windows musíte nejdřív nainstalovat NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1012"/>
-        <source>About %1</source>
-        <translation>O %1</translation>
+        <location filename="../mainwindow.ui" line="763"/>
+        <source>Uninstall NDISwrapper</source>
+        <translation>Odinstalovat NDISwrapper</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1013"/>
-        <source>Version: </source>
-        <translation>Verze:</translation>
+        <location filename="../mainwindow.ui" line="795"/>
+        <source>Net diagnostics</source>
+        <translation>Diagnostika sítě</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1014"/>
-        <source>Program for troubleshooting and configuring network for MX Linux</source>
-        <translation>Program pro řešení problémů a nastavení sítě pro MX Linux</translation>
+        <location filename="../mainwindow.ui" line="807"/>
+        <source>Ping</source>
+        <translation>Ping</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1016"/>
-        <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation>Vlastnická práva (c) MEPIS LLC a MX Linux</translation>
+        <location filename="../mainwindow.ui" line="813"/>
+        <location filename="../mainwindow.ui" line="930"/>
+        <source>Target URL:</source>
+        <translation>Cílové URL:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1017"/>
-        <source>%1 License</source>
-        <translation>Licence %1</translation>
-    </message>
-</context>
-<context>
-    <name>QApplication</name>
-    <message>
-        <location filename="../about.cpp" line="32"/>
-        <source>License</source>
-        <translation>Licence</translation>
+        <location filename="../mainwindow.ui" line="823"/>
+        <source>Packets</source>
+        <translation>Pakety</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="33"/>
-        <location filename="../about.cpp" line="43"/>
-        <source>Changelog</source>
-        <translation>Protokol změn</translation>
+        <location filename="../mainwindow.ui" line="865"/>
+        <location filename="../mainwindow.ui" line="985"/>
+        <source>Start</source>
+        <translation>Spustit</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="34"/>
+        <location filename="../mainwindow.ui" line="882"/>
+        <location filename="../mainwindow.ui" line="1002"/>
+        <source>Clear</source>
+        <translation>Vyčistit</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="896"/>
+        <location filename="../mainwindow.ui" line="1016"/>
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
     <message>
-        <location filename="../about.cpp" line="51"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Zavřít</translation>
+        <location filename="../mainwindow.ui" line="924"/>
+        <source>Traceroute</source>
+        <translation>Traceroute</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="44"/>
-        <source>You must run this program as root.</source>
-        <translation>Tuto aplikaci musíte spustit jako root.</translation>
+        <location filename="../mainwindow.ui" line="940"/>
+        <source>Hops</source>
+        <translation>Hops</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="509"/>
+        <location filename="../mainwindow.cpp" line="98"/>
+        <source>IP address from router:</source>
+        <translation>IP adresa z routru:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="99"/>
+        <source>External IP address:</source>
+        <translation>Externí IP adresa:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="135"/>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <source>Interface: %1</source>
+        <translation>Interface: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="135"/>
+        <location filename="../mainwindow.cpp" line="149"/>
+        <source>Driver: %1</source>
+        <translation>Ovladač: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="136"/>
+        <location filename="../mainwindow.cpp" line="150"/>
+        <source>Description: %1</source>
+        <translation>Popis: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="151"/>
+        <source>Product: %1</source>
+        <translation>Produkt: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="152"/>
+        <source>Vendor: %1</source>
+        <translation>Výrobce: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <location filename="../mainwindow.cpp" line="153"/>
+        <source>Enabled: %1</source>
+        <translation>Zapnuto: %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="206"/>
+        <location filename="../mainwindow.cpp" line="220"/>
+        <location filename="../mainwindow.cpp" line="234"/>
+        <source>&amp;Copy</source>
+        <translation>&amp;Kopírovat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="208"/>
+        <location filename="../mainwindow.cpp" line="222"/>
+        <location filename="../mainwindow.cpp" line="236"/>
+        <source>Ctrl+C</source>
+        <translation>Ctrl+C</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="209"/>
+        <location filename="../mainwindow.cpp" line="223"/>
+        <location filename="../mainwindow.cpp" line="237"/>
+        <source>Copy &amp;All</source>
+        <translation>Kopírovat &amp;vše</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="211"/>
+        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="239"/>
+        <source>Ctrl+A</source>
+        <translation>Ctrl+A</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="264"/>
+        <location filename="../mainwindow.cpp" line="282"/>
+        <source>Traceroute not installed</source>
+        <translation>Traceroute není nainstalován</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="265"/>
+        <source>Traceroute is not installed, do you want to install it now?</source>
+        <translation>Traceroute není nainstalován, přejete si ho nainstalovat?</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="272"/>
+        <source>Traceroute hasn&apos;t been installed</source>
+        <translation>Traceroute nebyl nainstalován</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="273"/>
+        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
+        <translation>Traceroute nemůže být nainstalován. Může to být způsobeno tím, že používáte LiveCD nebo nemáte přístup k softvérovým repozitářům.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="283"/>
+        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
+        <translation>Traceroute není nainstalován a nebylo rozpoznáno žádné připojení k Internetu, bez kterého nelze program nainstalovat.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="290"/>
+        <location filename="../mainwindow.cpp" line="329"/>
+        <source>No destination host</source>
+        <translation>Žádný cílový host</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="290"/>
+        <location filename="../mainwindow.cpp" line="329"/>
+        <source>Please fill in the destination host field</source>
+        <translation>Prosím vyplňte políčko cílový host</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="454"/>
+        <source>Loaded Drivers</source>
+        <translation>Načtené ovladače</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="462"/>
+        <source>Unloaded Drivers</source>
+        <translation>Nenačtené ovladače</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="475"/>
+        <source>Blocked Drivers</source>
+        <translation>Zakázané ovladače</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="494"/>
+        <source>Blocked Broadcom Drivers</source>
+        <translation>Zakázané ovladače Mobilního připojení</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="515"/>
         <source>Ndiswrapper is not installed</source>
         <translation>NDISwrapper není nainstalován</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="521"/>
+        <location filename="../mainwindow.cpp" line="527"/>
         <source>driver installed</source>
         <translation>Ovladač nainstalován</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../mainwindow.cpp" line="536"/>
         <source> and in use by </source>
         <translation>a používán</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="536"/>
+        <location filename="../mainwindow.cpp" line="543"/>
         <source>. Alternate driver: </source>
         <translation>. Alternativní ovladač:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="613"/>
+        <location filename="../mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovladač byl odstraněn se seznamu zakázaných</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ovladač byl odstraněn se seznamu zakázaných</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="620"/>
-        <location filename="../mainwindow.cpp" line="621"/>
         <source>Module blocked</source>
-        <translation type="unfinished"></translation>
+        <translation>Modul byl zakázán</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="786"/>
+        <location filename="../mainwindow.cpp" line="780"/>
         <source>Installation successful</source>
         <translation>Instalace úspěšná</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="789"/>
+        <location filename="../mainwindow.cpp" line="782"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
         <translation>Chyba, není možné zkompilovat ovladač NDISwrapper.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="792"/>
+        <location filename="../mainwindow.cpp" line="785"/>
         <source>Error detected, could not install ndiswrapper.</source>
         <translation>Chyba, není možné nainstalovat NDISwrapper.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="804"/>
+        <location filename="../mainwindow.cpp" line="797"/>
         <source>Error encountered while removing Ndiswrapper</source>
         <translation>Počas odstraňování NDISwrapper se vyskytly chyby</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="855"/>
+        <location filename="../mainwindow.cpp" line="844"/>
         <source>Unblock Driver</source>
-        <translation type="unfinished"></translation>
+        <translation>Povolit ovladač</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="858"/>
-        <source>Block Driver</source>
-        <translation type="unfinished"></translation>
+        <location filename="../mainwindow.cpp" line="876"/>
+        <source>enabled</source>
+        <translation>povoleno</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="995"/>
+        <location filename="../mainwindow.cpp" line="879"/>
+        <source>disabled</source>
+        <translation>zakázáno</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="882"/>
+        <source>WiFi hardware switch is off</source>
+        <translation>Hardvérový přepínač WiFi je v poloze vypnuto.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="890"/>
+        <source>Locate the Windows driver you want to add</source>
+        <translation>Určit ovladač z Windows, který si přejete přidat</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="891"/>
+        <source>Windows installation information file (*.inf)</source>
+        <translation>Windows installation information file (*.inf)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="921"/>
+        <source>*.sys file not found</source>
+        <translation>sobor *.sys nenalezen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="922"/>
+        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
+        <translation>Soubory *.sys musí být umístněny v stejné složce jako soubor *.inf. %1 nelze nalézt</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="933"/>
+        <source>sys file reference not found</source>
+        <translation>referene soboru *.sys nenalezena</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="934"/>
+        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
+        <translation>Po zanalyzování inf souboru nemůže být určen sys soubor daného ovladače</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="948"/>
+        <source>Ndiswrapper driver removed.</source>
+        <translation>Ovladač Ndiswrapper odstraněn.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="956"/>
+        <source>%1 Help</source>
+        <translation>Nápověda %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="965"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>Nebylo možné odblokovat zařízení.
 Zařízení WiFi by už mohlo být odblokováno(y).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="997"/>
+        <location filename="../mainwindow.cpp" line="967"/>
         <source>WiFi devices unlocked.</source>
         <translation>WiFi zařízení odblokovány.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1040"/>
-        <location filename="../mainwindow.cpp" line="1041"/>
+        <location filename="../mainwindow.cpp" line="978"/>
+        <source>About %1</source>
+        <translation>O programu %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="979"/>
+        <source>Version: </source>
+        <translation>Verze:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="981"/>
+        <source>Program for troubleshooting and configuring network for MX Linux</source>
+        <translation>Program pro řešení problémů a nastavení sítě pro MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="983"/>
+        <source>Copyright (c) MEPIS LLC and MX Linux</source>
+        <translation>Vlastnická práva (c) MEPIS LLC a MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="984"/>
+        <source>%1 License</source>
+        <translation>Licence %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1003"/>
         <source>Driver loaded successfully</source>
         <translation>Ovladač byl úspěšně načten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1056"/>
-        <location filename="../mainwindow.cpp" line="1057"/>
+        <location filename="../mainwindow.cpp" line="1018"/>
         <source>Driver unloaded successfully</source>
         <translation>Ovladač byl úspěšně uvolněn</translation>
     </message>
@@ -483,12 +523,43 @@ Zařízení WiFi by už mohlo být odblokováno(y).</translation>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="638"/>
+        <location filename="../about.cpp" line="52"/>
+        <source>License</source>
+        <translation>Licence</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="53"/>
+        <location filename="../about.cpp" line="62"/>
+        <source>Changelog</source>
+        <translation>Protokol změn</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="54"/>
+        <source>Cancel</source>
+        <translation>Zrušit</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="74"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Zavřít</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="64"/>
+        <source>Error</source>
+        <translation>Chyba</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="65"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="637"/>
         <source>Could not load </source>
         <translation>Nelze načíst</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="669"/>
+        <location filename="../mainwindow.cpp" line="661"/>
         <source>Could not unload </source>
         <translation>Nelze uvolnit</translation>
     </message>
